@@ -31,6 +31,8 @@ __all__ = (
     "GetAnalyzerResponseTypeDef",
     "ArchiveRuleSummaryTypeDef",
     "GetArchiveRuleResponseTypeDef",
+    "FindingSourceDetailTypeDef",
+    "FindingSourceTypeDef",
     "FindingTypeDef",
     "GetFindingResponseTypeDef",
     "InlineArchiveRuleTypeDef",
@@ -150,6 +152,22 @@ GetArchiveRuleResponseTypeDef = TypedDict(
     "GetArchiveRuleResponseTypeDef", {"archiveRule": ArchiveRuleSummaryTypeDef}
 )
 
+FindingSourceDetailTypeDef = TypedDict(
+    "FindingSourceDetailTypeDef", {"accessPointArn": str}, total=False
+)
+
+_RequiredFindingSourceTypeDef = TypedDict(
+    "_RequiredFindingSourceTypeDef", {"type": Literal["BUCKET_ACL", "POLICY", "S3_ACCESS_POINT"]}
+)
+_OptionalFindingSourceTypeDef = TypedDict(
+    "_OptionalFindingSourceTypeDef", {"detail": FindingSourceDetailTypeDef}, total=False
+)
+
+
+class FindingSourceTypeDef(_RequiredFindingSourceTypeDef, _OptionalFindingSourceTypeDef):
+    pass
+
+
 _RequiredFindingTypeDef = TypedDict(
     "_RequiredFindingTypeDef",
     {
@@ -178,6 +196,7 @@ _OptionalFindingTypeDef = TypedDict(
         "isPublic": bool,
         "principal": Dict[str, str],
         "resource": str,
+        "sources": List[FindingSourceTypeDef],
     },
     total=False,
 )
@@ -282,6 +301,7 @@ _OptionalFindingSummaryTypeDef = TypedDict(
         "isPublic": bool,
         "principal": Dict[str, str],
         "resource": str,
+        "sources": List[FindingSourceTypeDef],
     },
     total=False,
 )
